@@ -14,25 +14,21 @@
 #'   and the second element to the 'control' intervention of the comparison.
 #' @param drug_names A vector of labels with the name of the interventions
 #'   in the order they appear in the argument \code{data} of
-#'   \code{\link{run_model}}. If the argument \code{drug_names} is not defined,
-#'   the order of the interventions as they appear in
-#'   \code{data} is used, instead.
+#'   \code{\link{run_model}}.
 #'
-#' @return \code{balloon_plot} returns two enhanced balloon plots for one
+#' @return
+#'   \code{balloon_plot} returns two enhanced balloon plots for one
 #'   comparison (see 'Details'):
-#'   \tabular{ll}{
-#'    \code{Plot_effect_size} \tab The enhanced balloon plot for the
-#'    summary effect size (according to the argument \code{measure} inherited
-#'    by \code{\link{run_sensitivity}}) of one pairwise comparison.\cr
-#'    \tab \cr
-#'    \code{Plot_tau} \tab The enhanced balloon plot for tau. When the
-#'    fixed-effect model has been performed in \code{\link{run_sensitivity}},
-#'    the function will not return the \code{Plot_tau}.\cr
-#' }
+#'   \item{plot_effect_size}{The enhanced balloon plot for the
+#'   summary effect size (according to the argument \code{measure} inherited
+#'   by \code{\link{run_sensitivity}}) for one pairwise comparison.}
+#'   \item{plot_tau}{The enhanced balloon plot for \emph{tau}. When the
+#'   fixed-effect model has been performed in \code{\link{run_sensitivity}},
+#'   the function will not return the \code{plot_tau}.}
 #'
 #' @details
-#'   For the \code{Plot_effect_size} of the selected pairwise
-#'   comparison, the different colours and sizes of the bubbles reflect the
+#'   For the \code{plot_effect_size} of the selected pairwise comparison,
+#'   the different colours and sizes of the bubbles reflect the
 #'   posterior standard deviation and the posterior mean, respectively.
 #'   A colour key appears below the plot.
 #'   The size of the bubble is proportional to the corresponding posterior mean.
@@ -46,15 +42,15 @@
 #'   the x-axis refers to the 'experimental' intervention, and the y-axis refers
 #'   to the 'control' intervention.
 #'
-#'   The same enhanced balloon plot is created for tau (\code{Plot_tau}).
+#'   The same enhanced balloon plot is created for \emph{tau} (\code{plot_tau}).
 #'   However, filled bubbles indicate low statistical heterogeneity
-#'   (the posterior median of tau is lower than the median of the
+#'   (the posterior median of \emph{tau} is lower than the median of the
 #'   prior distribution for the heterogeneity parameter),
 #'   and crossed bubbles indicate considerable statistical heterogeneity
-#'   (the posterior median of tau exceeds the median of the prior
+#'   (the posterior median of \emph{tau} exceeds the median of the prior
 #'   distribution for the heterogeneity parameter).
 #'
-#'   \code{balloon_plot_mod} can be used only when missing participant
+#'   \code{balloon_plot} can be used only when missing participant
 #'   outcome data have been extracted for at least one trial.
 #'   Otherwise, the execution of the function will be stopped and an error
 #'   message will be printed on the R console.
@@ -67,7 +63,7 @@
 #' Spineli LM, Kalyvas C, Papadimitropoulou K. Quantifying the robustness of
 #' primary analysis results: A case study on missing outcome data in pairwise
 #' and network meta-analysis. \emph{Res Synth Methods}
-#' 2021;\bold{12}(4):475--490. \doi{10.1002/jrsm.1478}
+#' 2021;\bold{12}(4):475--490. doi: https://doi.org/10.1002/jrsm.1478
 #'
 #' @examples
 #' data("pma.taylor2004")
@@ -87,38 +83,51 @@
 #' @export
 balloon_plot <- function(sens, compar, drug_names) {
 
+  if (sens$type != "sens" || is.null(sens$type)) {
+    stop("'sens' must be an object of S3 class 'run_sensitivity'.",
+         call. = FALSE)
+  }
+
   if (any(is.na(sens))) {
     stop("No missing outcome data collected; function cannot be used.",
          call. = FALSE)
   }
 
-  es_all <- sens$EM
+  es_all <- if (is.element(sens$measure, c("RR", "RD"))) {
+    sens$EM_LOR
+  } else {
+    sens$EM
+  }
   D <- sens$D
   scenarios <- sens$scenarios
-  measure <- sens$measure
+  measure <- if (is.element(sens$measure, c("RR", "RD"))) {
+    "OR"
+  } else {
+    sens$measure
+  }
   tau_all <- sens$tau
 
   # Define the position and number of the scenarios
   nt <- (1 + sqrt(1 + 8 * (length(es_all[, 1]) / length(scenarios)^2))) / 2
 
   drug_names <- if (missing(drug_names)) {
-    stop("The argument 'drug_names' has not been defined", call. = FALSE)
+    stop("The argument 'drug_names' has not been defined.", call. = FALSE)
   } else {
     drug_names
   }
 
   compar <- if (missing(compar)) {
-    stop("The argument 'compar' needs to be defined", call. = FALSE)
+    stop("The argument 'compar' needs to be defined.", call. = FALSE)
   } else if (length(drug_names) < 3 & missing(compar)) {
     c(drug_names[2], drug_names[1])
   } else if (!is.element(compar[1], drug_names) |
              !is.element(compar[2], drug_names)) {
-    stop("The value of 'compar' is not found in the argument 'drug_names'",
+    stop("The value of 'compar' is not found in the argument 'drug_names'.",
          call. = FALSE)
   } else if (is.element(compar[1], drug_names) &
              is.element(compar[2], drug_names) &
              match(compar[1], drug_names) < match(compar[2], drug_names)) {
-    stop("Re-arrange the order of the element in the argument 'compar'",
+    stop("Re-arrange the order of the elements in the argument 'compar'.",
          call. = FALSE)
   } else if (is.element(compar[1], drug_names) &
              is.element(compar[2], drug_names) &
@@ -148,8 +157,10 @@ balloon_plot <- function(sens, compar, drug_names) {
       sd_es[i, j] <- round(es_all[j + (nt * (nt - 1) / 2) * (i - 1), 2], 2)
 
       # Standardise the effect estimate based on the outcome direction
-      es_stand[i, j] <- ifelse(D == 1, es[i, j] / sd_es[i, j],
-                               -es[i, j] / sd_es[i, j])
+      #es_stand[i, j] <- ifelse(D == 1, es[i, j] / sd_es[i, j],
+      #                         (-1) *(es[i, j] / sd_es[i, j]))
+      es_stand[i, j] <- ifelse(D == 1, es[i, j],
+                               (-1) *es[i, j])
 
       # Lower bound of the 95% credible interval of the effect estimate
       lower_es[i, j] <- es_all[j + (nt * (nt - 1) / 2) * (i - 1), 3]
@@ -158,7 +169,7 @@ balloon_plot <- function(sens, compar, drug_names) {
       upper_es[i, j] <- es_all[j + (nt * (nt - 1) / 2) * (i - 1), 4]
 
       # Dummy variable to indicate present or absent statistical significance
-      signif[i, j] <- ifelse(lower_es[i, j] < 0 & upper_es[i, j] > 0,
+      signif[i, j] <- ifelse(lower_es[i, j] > 0 || upper_es[i, j] < 0,
                              "yes", "no")
     }
   }
@@ -181,13 +192,13 @@ balloon_plot <- function(sens, compar, drug_names) {
   colnames(mat) <- c("active", "control", "value", "sd_value", "significance")
 
   # Enhanced balloon plot for summary effect size of the selected comparison
-  labels <- if (is.element(measure, c("OR", "ROM"))) {
+  labels <- if (is.element(measure, c("OR", "RR", "ROM"))) {
     as.character(fractions(exp(scenarios)))
   } else {
     as.character(scenarios)
   }
 
-  imp <- if (is.element(measure, "OR")) {
+  imp <- if (is.element(measure, c("OR", "RR", "RD"))) {
     "IMOR"
   } else if (is.element(measure, c("MD", "SMD"))) {
     "IMDoM"
@@ -195,7 +206,7 @@ balloon_plot <- function(sens, compar, drug_names) {
     "IMRoM"
   }
 
-  bubble_es <- if (is.element(measure, c("OR", "ROM"))) {
+  bubble_es <- if (is.element(measure, c("OR", "RR", "ROM"))) {
    ggplot(mat, aes(x = active,
                    y = control,
                    color = sd_value,
@@ -238,7 +249,7 @@ balloon_plot <- function(sens, compar, drug_names) {
            y = paste(imp, "scenario in", control),
            color = "") +
       guides(shape = "none", size = "none") +
-      ggtitle(paste("Summary", effect_measure_name(measure))) +
+      ggtitle(paste("Summary", effect_measure_name(measure, lower = TRUE))) +
       theme_bw() +
       theme(axis.text.x = element_text(size = 12,
                                        angle = 360,
@@ -259,7 +270,7 @@ balloon_plot <- function(sens, compar, drug_names) {
                                         face = "bold"),
             panel.grid.minor = element_blank(),
             panel.background = element_rect(fill = "grey86"))
-  } else if (is.element(measure, c("MD", "SMD"))) {
+  } else if (is.element(measure, c("MD", "RD", "SMD"))) {
     ggplot(mat, aes(x = active,
                     y = control,
                     color = sd_value,
@@ -301,7 +312,7 @@ balloon_plot <- function(sens, compar, drug_names) {
            y = paste(imp, "scenario in", control),
            color = "") +
       guides(shape = "none", size = "none") +
-      ggtitle(paste("Summary", effect_measure_name(measure))) +
+      ggtitle(paste("Summary", effect_measure_name(measure, lower = TRUE))) +
       theme_bw() +
       theme(axis.text.x = element_text(size = 12,
                                        angle = 360,
@@ -326,7 +337,7 @@ balloon_plot <- function(sens, compar, drug_names) {
 
   if (!is.null(sens$heter)) {
     # Posterior mean of tau
-    tau <- round(tau_all[, 1], 2)
+    tau <- round(tau_all[, 5], 2)
 
     # Posterior standard deviation of tau
     sd_tau <- round(tau_all[, 2], 2)
@@ -352,14 +363,14 @@ balloon_plot <- function(sens, compar, drug_names) {
   }
 
   # Enhanced balloon plot for the between-trial standard deviation
-  axis.name.x <- if (is.element(measure, "OR")) {
+  axis.name.x <- if (is.element(measure, c("OR", "RR", "RD"))) {
     "IMOR scenario in experimental"
   } else if (is.element(measure, c("MD", "SMD"))) {
     "IMDoM scenario in experimental"
   } else if (is.element(measure, "ROM")) {
     "IMRoM scenario in experimental"
   }
-  axis.name.y <- if (is.element(measure, "OR")) {
+  axis.name.y <- if (is.element(measure, c("OR", "RR", "RD"))) {
     "IMOR scenario in control"
   } else if (is.element(measure, c("MD", "SMD"))) {
     "IMDoM scenario in control"
