@@ -1,9 +1,9 @@
-#' Comparator-specific forest-plot for network meta-regression
+#' Comparator-specific forest plot for network meta-regression
 #'
 #' @description This function illustrates a forest plot of the posterior mean
-#'   and 95\% credible and predictive interval of comparisons with the selected
-#'   intervention of the network under the network meta-analysis and network
-#'   meta-regression.
+#'   and 95\% credible and prediction interval of comparisons with the selected
+#'   intervention of the network under the network meta-analysis \emph{and}
+#'   network meta-regression.
 #'
 #' @param full An object of S3 class \code{\link{run_model}}. See 'Value' in
 #'   \code{\link{run_model}}.
@@ -32,51 +32,59 @@
 #'   network; the selected intervention that comprises the \code{compar} is
 #'   indicated in the plot with a homonymous label. The numerical results are
 #'   displayed above each line.
-#'   Odds ratio and ratio of means are reported in the original scale after
-#'   exponentiation of the logarithmic scale.
-#'
-#'   When the covariate is binary, specify in the second element of
-#'   \code{cov_value} the name of the level for which the forest plot will be
-#'   created.
+#'   Odds ratio, relative risks, and ratio of means are reported in the original
+#'   scale after exponentiation of the logarithmic scale.
 #'
 #'   In both plots, the interventions are sorted in the descending order of
 #'   their SUCRA values based on the network meta-analysis.
 #'
+#'   \code{forestplot_metareg} is integrated in \code{\link{metareg_plot}}.
+#'
 #'   \code{forestplot} can be used only for a network of interventions. In the
 #'   case of two interventions, the execution of the function will be stopped
 #'   and an error message will be printed on the R console.
 #'
 #' @author {Loukia M. Spineli}
 #'
-#' @seealso \code{\link{run_metareg}}, \code{\link{run_model}}
+#' @seealso \code{\link{metareg_plot}}, \code{\link{run_metareg}},
+#'   \code{\link{run_model}}
 #'
 #' @references
 #' Salanti G, Ades AE, Ioannidis JP. Graphical methods and numerical summaries
 #' for presenting results from multiple-treatment meta-analysis: an overview and
 #' tutorial. \emph{J Clin Epidemiol} 2011;\bold{64}(2):163--71.
-#' \doi{10.1016/j.jclinepi.2010.03.016}
+#' doi: 10.1016/j.jclinepi.2010.03.016
 #'
 #' @export
 forestplot_metareg <- function(full, reg, compar, cov_value, drug_names) {
 
+  if (full$type != "nma" || is.null(full$type)) {
+    stop("The argument 'full' must be an object of S3 class 'run_model'.",
+         call. = FALSE)
+  }
+
+  if (reg$type != "nmr" || is.null(reg$type)) {
+    stop("The argument 'reg' must be an object of S3 class 'run_metareg'.",
+         call. = FALSE)
+  }
+
   if (length(unique(reg$covariate)) < 3 &
       !is.element(cov_value[[1]], reg$covariate)) {
     aa <- "The first element of the argument 'cov_value' is out of the value"
-    bb <- "range of the analysed covariate"
+    bb <- "range of the analysed covariate."
     stop(paste(aa, bb), call. = FALSE)
   } else if (length(unique(reg$covariate)) > 2 &
              (cov_value[[1]] < min(reg$covariate) |
               cov_value[[1]] > max(reg$covariate))) {
     aa <- "The first element of the argument 'cov_value' is out of the value"
-    bb <- "range of the analysed covariate"
+    bb <- "range of the analysed covariate."
     stop(paste(aa, bb), call. = FALSE)
   }
 
   drug_names <- if (missing(drug_names)) {
     aa <- "The argument 'drug_names' has not been defined."
-    bb <- "The intervention ID, as specified in 'data' is used as"
-    cc <- "intervention names"
-    message(cat(paste0("\033[0;", col = 32, "m", aa, bb, cc, "\033[0m", "\n")))
+    bb <- "The intervention ID, as specified in 'data' is used, instead."
+    message(paste(aa, bb))
     nt <- length(full$SUCRA[, 1])
     as.character(1:nt)
   } else {
@@ -85,7 +93,7 @@ forestplot_metareg <- function(full, reg, compar, cov_value, drug_names) {
   len_drug <- length(drug_names)
 
   if (length(drug_names) < 3) {
-    stop("This function is *not* relevant for a pairwise meta-analysis",
+    stop("This function is *not* relevant for a pairwise meta-analysis.",
          call. = FALSE)
   }
 
@@ -94,25 +102,29 @@ forestplot_metareg <- function(full, reg, compar, cov_value, drug_names) {
   drug_names_sorted <- drug_names[order(full$SUCRA[, 1], decreasing = TRUE)]
 
   compar <- if (missing(compar)) {
-    stop("The argument 'compar' has not been defined", call. = FALSE)
+    stop("The argument 'compar' has not been defined.", call. = FALSE)
   } else if (!is.element(compar, drug_names)) {
-    stop("The value of the argument 'compar' is not found in the 'drug_names'",
+    stop("The value of the argument 'compar' is not found in the 'drug_names'.",
          call. = FALSE)
   } else if (is.element(compar, drug_names)) {
     compar
   }
 
   cov_value <- if (!is.null(reg$beta_all) & missing(cov_value)) {
-    stop("The argument 'cov_value' has not been defined", call. = FALSE)
+    stop("The argument 'cov_value' has not been defined.", call. = FALSE)
   } else if (!is.null(reg$beta_all) & length(cov_value) < 2) {
     aa <- "The argument 'cov_value' must be a list with elements a number and"
-    stop(paste(aa, "a character"), call. = FALSE)
+    stop(paste(aa, "a character."), call. = FALSE)
   } else if (!is.null(reg$beta_all) & length(cov_value) == 2) {
     cov_value
   }
 
-  measure <- effect_measure_name(full$measure)
   model <- full$model
+  measure <- full$measure
+  em_full <- full$EM
+  pred_full <- full$EM_pred
+  sucra_full <- full$SUCRA
+
   cov_val <- ifelse(length(unique(reg$covariate)) < 3,
                     cov_value[[1]],
                     cov_value[[1]] - mean(reg$covariate))
@@ -125,17 +137,17 @@ forestplot_metareg <- function(full, reg, compar, cov_value, drug_names) {
   poss_pair_comp <- rbind(poss_pair_comp1, poss_pair_comp2)
 
   # Effect size of all possible pairwise comparisons (NMA)
-  em_ref00_nma <- cbind(rbind(data.frame(mean = full$EM[, 1],
-                                         lower = full$EM[, 3],
-                                         upper = full$EM[, 7]),
-                              data.frame(mean = full$EM[, 1] * (-1),
-                                         lower = full$EM[, 7] * (-1),
-                                         upper = full$EM[, 3] * (-1))),
+  em_ref00_nma <- cbind(rbind(data.frame(mean = em_full[, 1],
+                                         lower = em_full[, 3],
+                                         upper = em_full[, 7]),
+                              data.frame(mean = em_full[, 1] * (-1),
+                                         lower = em_full[, 7] * (-1),
+                                         upper = em_full[, 3] * (-1))),
                         poss_pair_comp)
   em_subset_nma <- subset(em_ref00_nma, em_ref00_nma[5] == compar)
   em_ref0_nma <- rbind(em_subset_nma[, 1:3], c(rep(NA, 3)))
-  sucra_new <- data.frame(full$SUCRA[, 1],
-                          drug_names)[order(match(data.frame(full$SUCRA[, 1],
+  sucra_new <- data.frame(sucra_full[, 1],
+                          drug_names)[order(match(data.frame(sucra_full[, 1],
                                                              drug_names)[, 2],
                                                   em_subset_nma[, 4])), 1]
   em_ref_nma <- em_ref0_nma[order(sucra_new, decreasing = TRUE), ]
@@ -161,12 +173,12 @@ forestplot_metareg <- function(full, reg, compar, cov_value, drug_names) {
   # Posterior results on the predicted estimates of comparisons with the
   # selected comparator as reference
   if (model == "RE") {
-    pred_ref00_nma <- cbind(rbind(data.frame(mean = full$EM_pred[, 1],
-                                             lower = full$EM_pred[, 3],
-                                             upper = full$EM_pred[, 7]),
-                                  data.frame(mean = full$EM_pred[, 1] * (-1),
-                                             lower = full$EM_pred[, 7] * (-1),
-                                             upper = full$EM_pred[, 3] * (-1))),
+    pred_ref00_nma <- cbind(rbind(data.frame(mean = pred_full[, 1],
+                                             lower = pred_full[, 3],
+                                             upper = pred_full[, 7]),
+                                  data.frame(mean = pred_full[, 1] * (-1),
+                                             lower = pred_full[, 7] * (-1),
+                                             upper = pred_full[, 3] * (-1))),
                             poss_pair_comp)
     pred_subset_nma <- subset(pred_ref00_nma, pred_ref00_nma[5] == compar)
     pred_ref0_nma <- rbind(pred_subset_nma[, 1:3], c(rep(NA, 3)))
@@ -191,9 +203,9 @@ forestplot_metareg <- function(full, reg, compar, cov_value, drug_names) {
     rownames(pred_ref_nma) <- rownames(pred_ref_nmr) <- NULL
   }
 
-  # Create a data-frame with credible and predictive intervals of comparisons
+  # Create a data-frame with credible and prediction intervals of comparisons
   # with the reference intervention
-  if (!is.element(measure, c("Odds ratio", "Ratio of means")) & model == "RE") {
+  if (!is.element(measure, c("OR", "RR", "ROM")) & model == "RE") {
     prepare_em_nma <- data.frame(as.factor(rep(rev(seq_len(len_drug)), 2)),
                                  rep(drug_names_sorted, 2),
                                  round(rbind(em_ref_nma, pred_ref_nma), 2),
@@ -209,8 +221,7 @@ forestplot_metareg <- function(full, reg, compar, cov_value, drug_names) {
                                   "mean", "lower", "upper",
                                   "interval")
     colnames(prepare_em_nmr) <- colnames(prepare_em_nma)
-  } else if (is.element(measure, c("Odds ratio", "Ratio of means")) &
-             model == "RE") {
+  } else if (is.element(measure, c("OR", "RR", "ROM")) & model == "RE") {
     prepare_em_nma <- data.frame(as.factor(rep(rev(seq_len(len_drug)), 2)),
                                  rep(drug_names_sorted, 2),
                                  round(rbind(exp(em_ref_nma),
@@ -228,8 +239,7 @@ forestplot_metareg <- function(full, reg, compar, cov_value, drug_names) {
                                   "mean", "lower", "upper",
                                   "interval")
     colnames(prepare_em_nmr) <- colnames(prepare_em_nma)
-  } else if (!is.element(measure, c("Odds ratio", "Ratio of means")) &
-             model == "FE") {
+  } else if (!is.element(measure, c("OR", "RR", "ROM")) & model == "FE") {
     prepare_em_nma <- data.frame(as.factor(rev(seq_len(len_drug))),
                                  drug_names_sorted,
                                  round(em_ref_nma, 2))
@@ -240,8 +250,7 @@ forestplot_metareg <- function(full, reg, compar, cov_value, drug_names) {
                                   "comparison",
                                   "mean", "lower", "upper")
     colnames(prepare_em_nmr) <- colnames(prepare_em_nma)
-  } else if (is.element(measure, c("Odds ratio", "Ratio of means")) &
-             model == "FE") {
+  } else if (is.element(measure, c("OR", "RR", "ROM")) & model == "FE") {
     prepare_em_nma <- data.frame(as.factor(rev(seq_len(len_drug))),
                                  drug_names_sorted,
                                  round(exp(em_ref_nma), 2))
@@ -258,28 +267,25 @@ forestplot_metareg <- function(full, reg, compar, cov_value, drug_names) {
                                        "Network meta-regression"),
                                      each = length(prepare_em_nma[, 1])))
 
-  # Forest plots on credible/predictive intervals of comparisons with the
+  # Forest plots on credible/prediction intervals of comparisons with the
   # selected comparator
   subtitle <- paste("Results for", cov_value[[2]],
                    ifelse(length(unique(reg$covariate)) < 3, " ",
                           cov_value[[1]]))
 
-  caption <- if (full$D == 0 & is.element(measure,
-                                          c("Odds ratio", "Ratio of means"))) {
-    paste("If", measure, "< 1, favours the first arm; if",
-          measure, "> 1, favours", compar)
-  } else if (full$D == 1 & is.element(measure,
-                                      c("Odds ratio", "Ratio of means"))) {
-    paste("If", measure, "< 1, favours", compar,
-          "; if", measure, "> 1, favours the first arm")
-  } else if (full$D == 0 & !is.element(measure,
-                                      c("Odds ratio", "Ratio of means"))) {
-    paste("If", measure, "< 0, favours the first arm; if",
-          measure, "> 0, favours", compar)
-  } else if (full$D == 1 & !is.element(measure,
-                                      c("Odds ratio", "Ratio of means"))) {
-    paste("If", measure, "< 0, favours", compar,
-          "; if", measure, "> 0, favours the first arm")
+  measure2 <- effect_measure_name(measure, lower = FALSE)
+  caption <- if (full$D == 0 & is.element(measure, c("OR", "RR", "ROM"))) {
+    paste(measure2, "< 1, favours the first arm.",
+          measure2, "> 1, favours", compar)
+  } else if (full$D == 1 & is.element(measure, c("OR", "RR", "ROM"))) {
+    paste(measure2, "< 1, favours", compar,
+          ".", measure2, "> 1, favours the first arm")
+  } else if (full$D == 0 & !is.element(measure, c("OR", "RR", "ROM"))) {
+    paste(measure2, "< 0, favours the first arm.",
+          measure2, "> 0, favours", compar)
+  } else if (full$D == 1 & !is.element(measure, c("OR", "RR", "ROM"))) {
+    paste(measure2, "< 0, favours", compar,
+          ".", measure2, "> 0, favours the first arm")
   }
 
   forest_plots <- if (model == "RE") {
@@ -291,7 +297,7 @@ forestplot_metareg <- function(full, reg, compar, cov_value, drug_names) {
                group = analysis,
                colour = analysis)) +
       geom_hline(yintercept = ifelse(!is.element(
-        measure, c("Odds ratio", "Ratio of means")), 0, 1),
+        measure, c("OR", "RR", "ROM")), 0, 1),
         lty = 1,
         size = 1,
         col = "grey60") +
@@ -322,26 +328,8 @@ forestplot_metareg <- function(full, reg, compar, cov_value, drug_names) {
                 position = position_dodge(width = 0.5),
                 inherit.aes = TRUE,
                 na.rm = TRUE) +
-      #geom_text(aes(x = 0.45,
-      #              y = ifelse(is.element(
-      #                measure, c("Odds ratio", "Ratio of means")), 0.2, -0.2),
-      #              label = ifelse(full$D == 0, "Favours first arm",
-      #                             paste("Favours", compar))),
-      #          size = 3.5,
-      #          vjust = 0,
-      #          hjust = 0,
-      #          color = "black") +
-      #geom_text(aes(x = 0.45,
-      #              y = ifelse(is.element(
-      #                measure, c("Odds ratio", "Ratio of means")), 1.2, 0.2),
-      #              label = ifelse(full$D == 0, paste("Favours", compar),
-      #                             "Favours first arm")),
-      #          size = 3.5,
-      #          vjust = 0,
-      #          hjust = 0,
-      #          color = "black") +
       labs(x = "",
-           y = measure,
+           y = measure2,
            colour = "Analysis",
            subtitle = subtitle,
            caption = caption) +
@@ -353,7 +341,7 @@ forestplot_metareg <- function(full, reg, compar, cov_value, drug_names) {
                          values = c("black", "#D55E00")) +
       geom_label(aes(x = unique(order[is.na(mean)]),
                      y = ifelse(!is.element(
-                       measure, c("Odds ratio", "Ratio of means")), -0.2, 0.65),
+                       measure, c("OR", "RR", "ROM")), -0.2, 0.65),
                      hjust = 0,
                      vjust = 1,
                      label = "Comparator intervention"),
@@ -362,7 +350,7 @@ forestplot_metareg <- function(full, reg, compar, cov_value, drug_names) {
                  fontface = "plain",
                  size = 4) +
       scale_y_continuous(trans = ifelse(!is.element(
-        measure, c("Odds ratio", "Ratio of means")), "identity", "log10")) +
+        measure, c("OR", "RR", "ROM")), "identity", "log10")) +
       coord_flip() +
       theme_classic() +
       theme(axis.text.x = element_text(color = "black", size = 12),
@@ -370,7 +358,7 @@ forestplot_metareg <- function(full, reg, compar, cov_value, drug_names) {
             axis.title.x = element_text(color = "black", face = "bold",
                                         size = 12),
             legend.position = "bottom",
-            legend.justification = c(0.23, 0),
+            legend.justification = c(0.43, 0),
             strip.text = element_text(color = "black", face = "bold",
                                       size = 12),
             legend.text =  element_text(color = "black", size = 12),
@@ -386,7 +374,7 @@ forestplot_metareg <- function(full, reg, compar, cov_value, drug_names) {
                group = analysis,
                colour = analysis)) +
       geom_hline(yintercept = ifelse(!is.element(
-        measure, c("Odds ratio", "Ratio of means")), 0, 1),
+        measure, c("OR", "RR", "ROM")), 0, 1),
         lty = 1,
         size = 1,
         col = "grey60") +
@@ -417,26 +405,8 @@ forestplot_metareg <- function(full, reg, compar, cov_value, drug_names) {
                 position = position_dodge(width = 0.5),
                 inherit.aes = TRUE,
                 na.rm = TRUE) +
-      #geom_text(aes(x = 0.45,
-      #              y = ifelse(is.element(
-      #                measure, c("Odds ratio", "Ratio of means")), 0.2, -0.2),
-      #              label = ifelse(full$D == 0, "Favours first arm",
-      #                             paste("Favours", compar))),
-      #          size = 3.5,
-      #          vjust = 0,
-      #          hjust = 0,
-      #          color = "black") +
-      #geom_text(aes(x = 0.45,
-      #              y = ifelse(is.element(
-      #                measure, c("Odds ratio", "Ratio of means")), 1.2, 0.2),
-      #              label = ifelse(full$D == 0, paste("Favours", compar),
-      #                             "Favours first arm")),
-      #          size = 3.5,
-      #          vjust = 0,
-      #          hjust = 0,
-      #          color = "black") +
       labs(x = "",
-           y = measure,
+           y = measure2,
            colour = "Analysis",
            subtitle = subtitle,
            caption = caption) +
@@ -447,7 +417,7 @@ forestplot_metareg <- function(full, reg, compar, cov_value, drug_names) {
                          values = c("black", "#D55E00")) +
       geom_label(aes(x = unique(order[is.na(mean)]),
                      y = ifelse(!is.element(
-                       measure, c("Odds ratio", "Ratio of means")), -0.2, 0.65),
+                       measure, c("OR", "RR", "ROM")), -0.2, 0.65),
                      hjust = 0,
                      vjust = 1,
                      label = "Comparator intervention"),
@@ -456,7 +426,7 @@ forestplot_metareg <- function(full, reg, compar, cov_value, drug_names) {
                  fontface = "plain",
                  size = 4) +
       scale_y_continuous(trans = ifelse(!is.element(
-        measure, c("Odds ratio", "Ratio of means")), "identity", "log10")) +
+        measure, c("OR", "RR", "ROM")), "identity", "log10")) +
       coord_flip() +
       theme_classic() +
       theme(axis.text.x = element_text(color = "black", size = 12),
